@@ -28,18 +28,13 @@ from ldeep.views.activedirectory import (
 )
 from ldeep.views.cache_activedirectory import CacheActiveDirectoryView
 from ldeep.views.constants import (
-    AUTHENTICATING_EKUS,
-    EXTENDED_RIGHTS_NAME_MAP,
     FILETIME_TIMESTAMP_FIELDS,
     FOREST_LEVELS,
     LDAP_SERVER_SD_FLAGS_OID_SEC_DESC,
-    MS_PKI_CERTIFICATE_NAME_FLAG,
-    MS_PKI_ENROLLMENT_FLAG,
-    OID_TO_STR_MAP,
     USER_ACCOUNT_CONTROL,
-    ADRights,
 )
 from ldeep.views.ldap_activedirectory import LdapActiveDirectoryView
+from ldeep.utils.protections import checkProtections
 
 
 class Ldeep(Command):
@@ -56,7 +51,6 @@ class Ldeep(Command):
                 return b64encode(o).decode("ascii")
 
         if verbose:
-            # self.__display(list(map(dict, records)), default)
             self.__display(records, default)
         else:
             k = 0
@@ -1426,19 +1420,22 @@ class Ldeep(Command):
                     object_class = result["objectClass"]
                     member_primary_group_id = result["objectSid"].split("-")[-1]
 
-                    if object_class == [
-                        "top",
-                        "person",
-                        "organizationalPerson",
-                        "user",
-                    ]:
+                    if any(
+                        cls in object_class
+                        for cls in [
+                            "user",
+                            "computer",
+                            "msDS-ManagedServiceAccount",
+                            "msDS-GroupManagedServiceAccount",
+                        ]
+                    ):
                         print(
                             "{g:>{width}}".format(
                                 g=user_prefix + member_dn,
                                 width=leading_sp + len(user_prefix + member_dn),
                             )
                         )
-                    elif object_class == ["top", "group"]:
+                    elif "group" in object_class:
                         print(
                             "{g:>{width}}".format(
                                 g=group_prefix + member_dn,
@@ -1467,7 +1464,7 @@ class Ldeep(Command):
             group_dn = results[0]["distinguishedName"]
             primary_group_id = results[0]["objectSid"].split("-")[-1]
 
-            # AS there is a result, we get the users within the group
+            # As there is a result, we get the users within the group
             results = self.engine.query(
                 self.engine.ACCOUNTS_IN_GROUP_FILTER(primary_group_id, group_dn)
             )
@@ -1478,9 +1475,17 @@ class Ldeep(Command):
                 dn = result["distinguishedName"]
                 object_class = result["objectClass"]
 
-                if object_class == ["top", "person", "organizationalPerson", "user"]:
+                if any(
+                    cls in object_class
+                    for cls in [
+                        "user",
+                        "computer",
+                        "msDS-ManagedServiceAccount",
+                        "msDS-GroupManagedServiceAccount",
+                    ]
+                ):
                     print(user_prefix + dn)
-                elif object_class == ["top", "group"]:
+                elif "group" in object_class:
                     print(group_prefix + dn)
                     if recursive:
                         primary_group_id = result["objectSid"].split("-")[-1]
@@ -2149,6 +2154,29 @@ def main():
 
     ldap = sub.add_parser("ldap", description="LDAP mode")
     cache = sub.add_parser("cache", description="Cache mode")
+    protections = sub.add_parser("protections", description="Protections mode")
+    protections.add_argument(
+        "-d", "--domain", required=True, help="The domain as NetBIOS or FQDN"
+    )
+    protections.add_argument(
+        "-s",
+        "--ldapserver",
+        required=True,
+        help="The LDAP server (IP or FQDN for Kerberos)",
+    )
+    protections.add_argument("-u", "--username", help="The username")
+    protections.add_argument(
+        "-p", "--password", help="The password used for the authentication"
+    )
+    protections.add_argument(
+        "-H", "--ntlm", help="NTLM hashes, format is LMHASH:NTHASH"
+    )
+    protections.add_argument(
+        "-k",
+        "--kerberos",
+        action="store_true",
+        help="For Kerberos authentication, ticket file should be pointed by $KRB5NAME env variable",
+    )
 
     ldap.add_argument(
         "-d", "--domain", required=True, help="The domain as NetBIOS or FQDN"
@@ -2265,6 +2293,18 @@ def main():
         except CacheActiveDirectoryView.CacheActiveDirectoryDirNotFoundException as e:
             error(e)
 
+    elif args.mode == "protections":
+        # Check protections (LDAP Signing & LDAPS Channel Binding)
+        checkProtections(
+            args.ldapserver,
+            args.username,
+            args.password,
+            args.ntlm,
+            args.domain,
+            args.kerberos,
+        )
+        exit()
+
     else:
         try:
             # Authentication
